/**
 * Returns the original items array if it exists and is non-empty.
 * Otherwise, returns an array of placeholder values (`undefined`) with the specified length.
 *
 * Useful for rendering placeholder elements in UI when data is still loading.
 *
 * @template T - The type of items in the array.
 * @param {T[] | undefined} items - The array of items to use if available.
 * @param {number | undefined} placeholders - The number of placeholder entries to return if items are empty or undefined.
 * @returns {(T | undefined)[]} An array containing either the original items or placeholders (`undefined`).
 */
export declare function withPlaceholders<T>(items?: T[], placeholders?: number): (T | undefined)[];
