import { Reactive } from 'vue';
/**
 * Defines a reactive store with the provided ID and setup function.
 * This store will be registered and reused if already exists.
 *
 * @param id - A unique identifier for the store.
 * @param setup - A function to initialize the store's state.
 * @returns The reactive store instance.
 */
export declare function defineStore<State extends object>(id: string, setup: () => State): () => Reactive<State>;
/**
 * Defines a persistent store that supports encryption/decryption and saves to localStorage.
 * The store state is encrypted before saving and decrypted when loading.
 *
 * @param id - A unique identifier for the persistent store.
 * @param setup - A function to initialize the store's state.
 * @returns The reactive persistent store instance.
 */
export declare function definePersistentStore<State extends object>(id: string, setup: () => State): () => Reactive<State>;
